pub enum Event {
Quit,
LibraryChanged(MusicLibrary),
PlaybackEvent(PlaybackEvent),
CanRaiseChanged(bool),
CanGoFullscreenChanged(bool),
CanQuitChanged(bool),
}Expand description
Event from the daemon received in Response::Event.
Variants
Quit
Sent before the daemon quits.
LibraryChanged(MusicLibrary)
Sent after the contents of the music library have changed.
PlaybackEvent(PlaybackEvent)
Event originating from the playback module of the daemon.
CanRaiseChanged(bool)
Sent when the can_raise property of the daemon config changes.
CanGoFullscreenChanged(bool)
Sent when the can_go_fullscreen property of the daemon config changes.
CanQuitChanged(bool)
Sent when the can_quit property of the daemon config changes.