SocketType

Enum SocketType 

pub enum SocketType {
    NamespacedOnly,
    NamespacedOrFilesystem,
    FilesystemOnly,
}
Defines the socket type to use when attempting to connect to a daemon.

Variants



NamespacedOnly

Only use a namespaced socket with no fallback.

The connection will fail if a namespaced socket with the specified name doesn’t exist.



NamespacedOrFilesystem

Use a namespaced socket when possible, but allow a fallback to a filesystem socket.

The connection will fail if there are no namespaced or filesystem sockets with the specified name.



FilesystemOnly

Only use a filesystem socket with no fallback.

The connection will fail if a filesystem socket with the specified name doesn’t exist.