Command

Enum Command 

pub enum Command {
    Shutdown,
    Library(LibraryCommand),
    EventStream,
    Disconnect,
    Playback(PlaybackCommand),
    Ping,
}
Command that can be executed by a daemon instance.

The expected response may be different depending on the command sent. If it isn’t specified in the variant documentation, assume Response::Ok is the expected response.

Variants



Shutdown

Stop the daemon instance.

After sending this command, the daemon will close almost immediately, so all connections to it should be considered closed.



Library(LibraryCommand)

Subcommand for managing the music library.



EventStream

Stream events from the daemon.

The daemon will stop accepting requests from the connection this command was executed on.



Disconnect

Close the connection to the daemon.



Playback(PlaybackCommand)

Command to the playback module.



Ping

Ping the daemon.

The daemon will respond to this with Response::Pong if successful.