pub enum Error {
EncodingError,
DecodingError,
ConnectionError,
SendingError,
LibraryError(LibraryError),
InvalidResponse,
PlaybackError(PlaybackError),
SocketError(String),
}Expand description
Error related to the daemon.
Can either originate from a Response or from a function in this crate.
Variants
EncodingError
The provided command could not be encoded.
DecodingError
The daemon response could not be decoded.
ConnectionError
Could not connect to the daemon.
SendingError
Could not send the command to the daemon.
LibraryError(LibraryError)
Error related to the music library.
InvalidResponse
The response received from the daemon was unexpected or invalid.
PlaybackError(PlaybackError)
Error related to the playback module.
SocketError(String)
Could not obtain a socket